### Klecka, Jan: The role of a water bug, Sigara striata, in freshwater food webs
### R script documenting the analyses conducted in R and JAGS
### JAGS and an R package rjags need to be installed to run the analyses
########################################################################

### 1 ###
###Bayesian estimation of mortality rates of prey in the presence/absence of Sigara
###################################################################################

Sig.prey <- read.csv("Sig.prey.csv")
attach(Sig.prey)

#Load the library
require(rjags)

#number of observations
N=dim(Sig.prey)[1]

## list of data for JAGS
data_1 <- list(Sig=Sigara.presence,consumed=prey.consumed,n=prey.initial,N=N,prey=prey.id)

model_1=jags.model("prey.bug",data=data_1,n.chains=3) 
# initial values are drawn randomly from priors

# burn-in of the model
update(model_1,n.iter=1000)

# posterior parameters we want to analyse
parameters_1 <- c("a","b","pred_control","pred_Sig") 

#number of iterations
nit <- 100000
#thinning
thin <-100

output_1=coda.samples(model=model_1,variable.names=parameters_1,n.iter=nit,thin=thin)

# summary statistics for the posterior.
summary(output_1)

# plot trace and posterior probability density
plot(output_1)

# plot autocorelation
acfplot(output_1)

#Convergence analysis
gelman.diag(output_1) #the desired value is 1.00, should not be larger than ca. 1.2

geweke.diag(output_1) #values should be in the interval of +- 2 SD

### end 1 ###
#############


### 2 ###
###Bayesian estimation of mortality rate of Sigara caused by different predators
################################################################################

Sig.mort.full <- read.csv("Sig.mort.full.csv")
attach(Sig.mort.full)

#Load the library
require(rjags)

#number of observations
N=dim(Sig.mort.full)[1]

## a list of data for JAGS
data_2 <- list(consumed=Sigara.consumed,n=Sigara.initial,N=N,predator=pred.id)

model_2=jags.model("predator_species.bug",data=data_2,n.chains=3) 
# initial values are drawn randomly from priors

# burn-in of the model
update(model_2,n.iter=1000)

# posterior parameters we want to analyse
parameters_2 <- c("intercept","b","pred","SD_interspecific","SD_intraspecific") 

#number of iterations
nit <- 100000
#thinning
thin <-100

output_2=coda.samples(model=model_2,variable.names=parameters_2,n.iter=nit,thin=thin)

# summary statistics for the posterior.
summary(output_2)

# plot trace and posterior probability density
plot(output_2)

# plot autocorelation
acfplot(output_2)

# Convergence analysis
gelman.diag(output_2) #the desired value is 1.00, should not be larger than 1.2

geweke.diag(output_2) #values should be in the interval of +- 2 SD

### end 2 ###
#############


### 3 ###
###Bayesian estimation of mortality rate of Sigara depending on predator body mass
##################################################################################

Sigara_traits <- read.csv("Sigara_traits.csv")
attach(Sigara_traits)

#Load the library
require(rjags)   # to interface R with JAGS 
set.seed(123)

#number of observation
N=dim(Sigara_traits)[1]

## a list of data for JAGS
data_3 <- list(consumed=Sigara.consumed,n=Sigara.initial,
              N=N,mass=mass,predator=pred.id)

model_3=jags.model("traits_mass.bug",data=data_3,n.chains=3) 

# burn-in of the model
update(model_3,n.iter=1000)

# posterior parameters we want to analyse
parameters_3 <- c( "intercept","a1","SD_interspecific","SD_intraspecific") 

# number of iterations
nit <- 100000
# thinning
thin <-100

output_3=coda.samples(model=model_3,variable.names=parameters_3,n.iter=nit,thin=thin)
# initial values are drawn randomly from priors

# summary statistics for the posterior.
summary(output_3)

# plot trace and posterior probability density
plot(output_3)

# plot autocorelation
acfplot(output_3)

#Convergence analysis
gelman.diag(output_3) #the desired value is 1.00, should not be larger than 1.2

geweke.diag(output_3) #values should be in the interval of +- 2 SD

### end 3 ###
#############


### 4 ###
###Bayesian estimation of mortality rate of Sigara depending on multiple predator traits - full model
#####################################################################################################
Sigara_traits <- read.csv("Sigara_traits.csv")
attach(Sigara_traits)

#Load the library
require(rjags) 

#number of observations
N=dim(Sigara_traits)[1]

## a list of data for JAGS
data_4 <- list(consumed=Sigara.consumed,n=Sigara.initial,
              N=N,mass=mass,ambush=ambush,suctorial=suctorial,pelagic=pelagic,predator=pred.id)

model_4=jags.model("traits_full.bug",data=data_4,n.chains=3) 

# burn-in of the model
update(model_4,n.iter=1000)

# posterior parameters we want to analyse
parameters_4 <- c( "a1","a2","a3","a4","a5","intercept","SD_interspecific","SD_intraspecific") 

#number of iterations
nit <- 100000
#thinning
thin <-100

output_4=coda.samples(model=model_4,variable.names=parameters_4,n.iter=nit,thin=thin)
# initial values are drawn randomly from priors

# summary statistics for the posterior.
summary(output_4)

# plot trace and posterior probability density
plot(output_4)

# plot autocorelation
acfplot(output_4)

#Convergence analysis
gelman.diag(output_4) #the desired value is 1.00, should not be larger than 1.2

geweke.diag(output_4) #values should be in the interval of +- 2 SD

### end 4 ###
#############


### 5 ###
###Bayesian estimation of mortality rate of Sigara depending on multiple predator traits - reduced model
#####################################################################################################

Sigara_traits <- read.csv("Sigara_traits.csv")
attach(Sigara_traits)

#Load the library
require(rjags)

#number of observations
N=dim(Sigara_traits)[1]

## Define a list of data for JAGS
data_5 <- list(consumed=Sigara.consumed,n=Sigara.initial,
              N=N,mass=mass,ambush=ambush,suctorial=suctorial,pelagic=pelagic,predator=pred.id)

model_5=jags.model("traits_reduced.bug",data=data_5,n.chains=3) 


update(model_5,n.iter=1000)

parameters_5 <- c( "a1","a3","a4","intercept","SD_interspecific","SD_intraspecific") 

#number of iterations
nit <- 100000
#thinning
thin <-100

output_5=coda.samples(model=model_5,variable.names=parameters_5,n.iter=nit,thin=thin)


# summary statistics for the posterior.
summary(output_5)

# plot trace and posterior probability density
plot(output_5)

# plot autocorelation
acfplot(output_5)

#Convergence analysis
gelman.diag(output_5) #the desired value is 1.00, should not be larger than 1.2

geweke.diag(output_5) #values should be in the interval of +- 2 SD


### end 5 ###
#############

### the end of the script ###
#############################